#ifndef AONLICENSEWINDOW_H
#define AONLICENSEWINDOW_H

#include "controls/dialogwindow.h"

namespace Ui {
    class AonLicenseWindow;
}

class AonLicenseWindow : public DialogWindow
{
    Q_OBJECT

public:
    explicit AonLicenseWindow(QWidget *parent = 0);
    ~AonLicenseWindow();

private:
    Ui::AonLicenseWindow *ui;

private slots:
    void AcceptSlot(bool);
    void OkSlot();

};

#endif // AONLICENSEWINDOW_H
